import type { Style, Transform } from '../types';
/** Parse a css value for border */
export declare function border(value: string): {
    [x: string]: string;
};
/** Parse a css value for border-like elements */
export declare function borderLike(prefixKey: 'outline' | 'borderLeft' | 'borderRight' | 'borderTop' | 'borderBottom', value: string): {
    [x: string]: string;
};
export declare function shadow(prefix: 'textShadow' | 'shadow', value: string): {
    [x: string]: string | {
        width: string;
        height: string;
    };
};
export declare function flex(value: string): {
    flexBasis: string;
    flexGrow?: undefined;
    flexShrink?: undefined;
} | {
    flexGrow: string;
    flexBasis: string;
    flexShrink?: undefined;
} | {
    flexGrow: string;
    flexShrink: string;
    flexBasis: string;
};
export declare function flexFlow(value: string): {
    [prop: string]: string;
};
export declare function placeContent(value: string): {
    alignContent: string;
    justifyContent: string;
};
export declare function background(value: string): {
    backgroundColor: string;
    background: string;
} | {
    backgroundColor: string;
    background?: undefined;
};
export declare function textDecoration(value: string): {
    textDecorationLine: string;
    textDecorationStyle: string;
    textDecorationColor: string;
};
export declare function transform(value: string): {
    transform: Transform[];
};
export declare function font(value: string): Style;
/** Parses a css value for the side of an element (border-width, margin, padding) */
export declare function sideValue<T extends 'padding' | 'margin' | 'border' | 'outline'>(prefixKey: T, value: string, postFix?: T extends 'border' | 'outline' ? 'Width' | 'Style' | 'Color' | '' : ''): {
    [x: string]: string;
};
/** Parses a css value for the corner of an element (border-radius) */
export declare function cornerValue(prefixKey: 'border', value: string, postFix: 'Radius'): {
    [x: string]: string;
};
