import { MouseEvent } from 'react';
import type { Style, Units, MediaQuery } from './types';
import { LayoutChangeEvent, GestureResponderEvent, TouchableHighlightProps, TextInputProps } from 'react-native';
/** Hook that will apply the screen size to the styles defined with vmin, vmax, vw, vh units, and handle media queries constraints */
export declare const useScreenSize: () => {
    vw: number;
    vh: number;
    vmin: number;
    vmax: number;
    dvw: number;
    dvh: number;
    lvw: number;
    lvh: number;
    svw: number;
    svh: number;
};
/** Hook that will apply the style reserved for hover state if needed */
export declare const useHover: (onMouseEnter: ((event: MouseEvent) => void) | undefined, onMouseLeave: ((event: MouseEvent) => void | undefined) | undefined, needsHover: boolean) => {
    hover: boolean;
    onMouseEnter: ((event: MouseEvent) => void) | undefined;
    onMouseLeave: ((event: MouseEvent) => void | undefined) | undefined;
};
/** Hook that will apply the style reserved for active state if needed */
export declare const useActive: (onPressIn: ((event: GestureResponderEvent) => void) | undefined, onPressOut: ((event: GestureResponderEvent) => void) | undefined, onResponderStart: ((event: GestureResponderEvent) => void) | undefined, onResponderRelease: ((event: GestureResponderEvent) => void) | undefined, onStartShouldSetResponder: ((event: GestureResponderEvent) => void) | undefined, needsTouch: boolean) => {
    active: boolean;
    onPressIn: ((event: GestureResponderEvent) => void) | undefined;
    onPressOut: ((event: GestureResponderEvent) => void) | undefined;
    onResponderStart: ((event: GestureResponderEvent) => void) | undefined;
    onResponderRelease: ((event: GestureResponderEvent) => void) | undefined;
    onStartShouldSetResponder: ((event: GestureResponderEvent) => void) | undefined;
};
export declare type FocusEventListener = TouchableHighlightProps['onFocus'] | TextInputProps['onFocus'];
export declare type BlurEventListener = TouchableHighlightProps['onBlur'] | TextInputProps['onBlur'];
/** Hook that will apply the style reserved for active state if needed */
export declare const useFocus: (onFocus: undefined | FocusEventListener, onBlur: undefined | BlurEventListener, needsFocus: boolean) => {
    focused: boolean;
    onFocus: FocusEventListener;
    onBlur: BlurEventListener;
};
/** Hook that will apply the style provided in the media queries */
export declare const useMediaQuery: (media: undefined | MediaQuery[], units: Units) => Style | undefined;
/** Hook that will measure the layout to handle styles that use % units */
export declare const useLayout: (onLayout: ((event: LayoutChangeEvent) => void) | undefined, needsLayout: boolean) => {
    width: number;
    height: number;
    onLayout: ((event: LayoutChangeEvent) => void) | undefined;
};
/** Apply the new fontSize to the component before we can calculate em units */
export declare const useFontSize: (fontSizeTarget: string | undefined, rem: number, em: number) => {
    em: number;
};
